==> create-fly-1.21.11-pre1-6.0.8-1-sources.jar: com/zurrtum/create/infrastructure/packet/c2s/LinkedControllerInputPacket.java <==
package com.zurrtum.create.infrastructure.packet.c2s;

import com.zurrtum.create.AllHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecs;
import io.netty.buffer.ByteBuf;

import java.util.Collection;
import java.util.List;
import java.util.function.BiConsumer;
import net.minecraft.class_2338;
import net.minecraft.class_3244;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public record LinkedControllerInputPacket(List<Integer> activatedButtons, boolean press, class_2338 lecternPos) implements C2SPacket {
    public static final class_9139<ByteBuf, LinkedControllerInputPacket> CODEC = class_9139.method_56436(
        class_9135.field_49675.method_56433(class_9135.method_56363()),
        LinkedControllerInputPacket::activatedButtons,
        class_9135.field_48547,
        LinkedControllerInputPacket::press,
        CatnipStreamCodecs.NULLABLE_BLOCK_POS,
        LinkedControllerInputPacket::lecternPos,
        LinkedControllerInputPacket::new
    );

    public LinkedControllerInputPacket(Collection<Integer> activatedButtons, boolean press) {
        this(activatedButtons, press, null);
    }

    public LinkedControllerInputPacket(Collection<Integer> activatedButtons, boolean press, class_2338 lecternPos) {
        this(List.copyOf(activatedButtons), press, lecternPos);
    }

    @Override
    public boolean runInMain() {
        return true;
    }

    @Override
    public class_9145<LinkedControllerInputPacket> method_65080() {
        return AllPackets.LINKED_CONTROLLER_INPUT;
    }

    @Override
    public BiConsumer<class_3244, LinkedControllerInputPacket> callback() {
        return AllHandle::onLinkedControllerInput;
    }
}

==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/infrastructure/packet/c2s/LinkedControllerInputPacket.java <==
package com.zurrtum.create.infrastructure.packet.c2s;

import com.zurrtum.create.AllHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecs;
import io.netty.buffer.ByteBuf;
import java.util.Collection;
import java.util.List;
import net.minecraft.class_2338;
import net.minecraft.class_2596;
import net.minecraft.class_2792;
import net.minecraft.class_3244;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public record LinkedControllerInputPacket(
    List<Integer> activatedButtons, boolean press, class_2338 lecternPos
) implements class_2596<class_2792> {
    public static final class_9139<ByteBuf, LinkedControllerInputPacket> CODEC = class_9139.method_56436(
        class_9135.field_49675.method_56433(class_9135.method_56363()),
        LinkedControllerInputPacket::activatedButtons,
        class_9135.field_48547,
        LinkedControllerInputPacket::press,
        CatnipStreamCodecs.NULLABLE_BLOCK_POS,
        LinkedControllerInputPacket::lecternPos,
        LinkedControllerInputPacket::new
    );

    public LinkedControllerInputPacket(Collection<Integer> activatedButtons, boolean press) {
        this(activatedButtons, press, null);
    }

    public LinkedControllerInputPacket(Collection<Integer> activatedButtons, boolean press, class_2338 lecternPos) {
        this(List.copyOf(activatedButtons), press, lecternPos);
    }

    @Override
    public void handle(class_2792 listener) {
        AllHandle.onLinkedControllerInput((class_3244) listener, this);
    }

    @Override
    public class_9145<LinkedControllerInputPacket> method_65080() {
        return AllPackets.LINKED_CONTROLLER_INPUT;
    }
}
